onChangedMulti property
Called when the user selects items from the picker (multi-selection).
Implementation
final ValueChanged<List<T>>? onChangedMulti;
Called when the user selects items from the picker (multi-selection).
final ValueChanged<List<T>>? onChangedMulti;