selectPickerTopSelectorStyle property
Customization style for the top header of the bottom sheet.
Implementation
final SelectPickerTopSelectorStyle? selectPickerTopSelectorStyle;
Customization style for the top header of the bottom sheet.
final SelectPickerTopSelectorStyle? selectPickerTopSelectorStyle;