selectpicker library
A modern and legacy Select Picker library for Flutter.
Classes
- SelectPicker
- A legacy Select Picker widget.
- SelectPickerBottomSheetStyle
- Customization styles for the legacy SelectPicker bottom sheet.
- SelectPickerCardItemStyle
- Customization styles for the legacy SelectPicker list items.
- SelectPickerInputSearchStyle
- Customization styles for the legacy SelectPicker search input field.
- SelectPickerInputStyle
- Customization styles for the legacy SelectPicker input field.
- SelectPickerItem
- A model representing an item in the legacy SelectPicker.
-
SelectPickerNew<
T> -
A modern, generic Select Picker widget that supports any data type
T. - SelectPickerTheme
- An inherited widget that defines the configuration for SelectPickerNew in this widget's subtree.
- SelectPickerThemeData
- Defines the visual properties for SelectPickerNew.
- SelectPickerTopSelectorStyle
- Customization styles for the legacy SelectPicker top header area.